@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 from __future__ import division, print_function, absolute_import
 
 from os.path import join
@@ -21,19 +20,9 @@ def configuration(parent_package='',top_path=None):
         depends=statlib_src
     )
 
-    # add vonmises_cython module
-    config.add_extension('vonmises_cython',
-        sources=['vonmises_cython.c'],  # FIXME: use cython source
-    )
-
-    # add _rank module
-    config.add_extension('_rank',
-        sources=['_rank.c'],          # FIXME: use cython source
-    )
-
-    # add futil module
-    config.add_extension('futil',
-        sources=['futil.f'],
+    # add _stats module
+    config.add_extension('_stats',
+        sources=['_stats.c'],
     )
 
     # add mvn module
@@ -43,6 +32,7 @@ def configuration(parent_package='',top_path=None):
 
     return config
 
+
 if __name__ == '__main__':
     from numpy.distutils.core import setup
     setup(**configuration(top_path='').todict())
